from sqlalchemy import create_engine
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import sessionmaker
from mooc.core.config import settings
from typing import Generator
# 创建数据库引擎
engine = create_engine(
    settings.SQLALCHEMY_DATABASE_URI,
    pool_pre_ping=True,
    echo=settings.SQLALCHEMY_ECHO
)

# 创建会话工厂
SessionLocal = sessionmaker(autocommit=False, autoflush=False, bind=engine)

# 创建基类
Base = declarative_base()

def init_db():
    """初始化数据库"""
    Base.metadata.create_all(bind=engine)

def get_db() -> Generator:
    """
    获取数据库会话的依赖项
    """
    try:
        db = SessionLocal()
        yield db
    finally:
        db.close()